bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 31. Aventiure
___________________________________________________
| ### <Mir> chvlent so di ringe so sprach Volker ### ia wæne div naht vns welle nv niht wern mer ### ich chivs ez von dem lvfte ez ist schiere tach ### do wachten si do manigen der noch slaffende lach [383b] ### Do erschein der liehte morgen den gesten in den sal ### Hagen begonde wechen di ritter veber al ### ob si zv dem mvenster cer messe wolden gan ### nach sitten cristenliche man vil livten began
###### 1848 | ### Si svngen vngeliche daz da vil wol schein ### christen vnde heiden di warn niht enein ### do wolden zv der kirchen di Gventheres man ### si waren von den betten al geliche gestan
| ### Do næten sich di rechen in also gvt gewant ### daz nie helde mære in deheines chveneges lant ### ie bezzer kleider braten daz was Hagenen leit ### er sprach ia svlt ir helde hi tragen anderiv chleit
###### 1850 | ### Ia sint iv doch genvgen div mære wol bechant ### nv traget fver di rosen div waffen an der hant ### fver shapel wol gesteinet di liehten helme gvt ### sit daz wir wol erchennen der argen Criemhilden mvot
###### 1851 | ### Wir mvzen hivte <striten> daz wil ich iv sagen ### ir svlt fver siden hemde di halsperge tragen ### vnd fver di richen mentel di gvten schilde wit ### ob iemen mit iv zvrne daz ir vil wêrliche sit
| ### Mine lieben dar zv mage vnd man ### ir svlt vil willechlichen zv der kirchen gan ### vnde chlaget got dem richen iwer sorge vnd iwer not ### vnd wizzet sicherlichen daz vns nahet der tot
###### 1853 | ### Irn svlt ovch niht vergezen swaz ir habet getan ### vnde svlt vil vlizzechliche da gein gote stan ### des wil ich ivch warnen rechen vil her ### ezen welle got von himle ir vernemet messe nimmer mer
###### 1854 | ### Svs giengen zv dem mvenster di fvrsten vnd ir man ### vf dem vronem vrithove da hiez si stille stan ### Hagen der chvene daz si sich schieden niht ### er sprach ia weiz ez noch niemen waz von den Hivnen vns geschit
| ### Leget mine frivnde di schilde fver den fvz ### vnde geltet ob iv iemen welle bieten swachen grvz ### mit tieffen verchwnden daz ist Hagenen rat ### daz ir so werdet fvden daz ez iv lobelichen stat
###### 1856 | ### Volker vnd Hagene di zwene giengen [384a] dan ### fver daz wite mvenster daz wart dvrh daz getan ### daz si daz wolden wizen daz des chveneges wip ### mvse mit in dringen ia was vil grimmech ir lip
###### 1857 | ### Do chom der wirt des landes vnd ovh sin schoene wip ### mit richem gewande gezieret was ir lip ### vnd ovch vil sneller rechen di man sach mit ir varn ### do chos man hohe stovben von der Criemhilde scharn
| ### Do der chvenech riche svs gewaffent sach ### di chvenege vnd ir gesinde wi balde er do sprach ### wi sihe ich frivnde mine vnder helme gan ### mir ist leit vf mine triwe vnd hat in iemen iht getan
###### 1859 | ### Ich solz in bvezen gerne swi <si> dvnchet gvt ### hat iemen in besweret daz herce vnd ovch den mvt ### des bringe ich si wol innen daz ez mir ist vil leit ### swaz si mir gebietent des pin ich in alles bereit
###### 1860 | ### Des antwrte Hagene vns hat niemen niht getan ### ez <ist> sitte miner herren daz si gewaffent gan ### zallen hohgeziten ce vollen drien tagen ### swaz man vns hi getæte wir soltenz Eceln sagen
| ### Vil wol horte Criemhilt waz do Hagen sprach ### wi rehte fientliche si im vnder sach ### sine wolde doch niht melden den site von ir lant ### swi lange si den hete daz cen Bvrgonden bechant
###### 1862 | ### Swi grimme vnd swi starch si in vient wære ### het im iemen gesagt div rehten mære ### er het wol vnderstanden daz doch sit da geshach ### dvrch ir vil starche vbermvt ir deheiner im es veriach
###### 1863 | ### Do gi vil groziv menege mit der chveneginne dan ### done wolden dise zwene doch niht hoher stan ### zweir hande breite daz was den Hivnen leit ### ia <mvsen> si sich dringen mit den helden gemeit
| ### Eceln kamerære dine dvhte daz niht gvt ### ia heten si den rechen erzvernet do den mvt ### wan daz sine torsten vor dem chvenege her ### da was vil michel dringen vnt do niht anders mer
###### 1865 | ### Do man da gote gediende vnt daz si [384b] wolden dan ### vil balde chom cen rossen vil manech Hivnen man ### do was bi Criemhilde manech schoniv meit ### wol siben tvsent degene bi der chveneginne reit
###### 1866 | ### Criemhilt mit ir vrowen in div venster gesaz ### zv Ecel dem richen vil liep was im daz ### si wolden schowen riten di helde vil gemeit ### hey waz vremder recken vor in vf dem hove reit
| ### Do was ovch der marschalch mit den knehten chomen ### Danchwart der vil chvene der het zv zim genomen ### sines herren ingesinde von Bvergonden lant ### div ross man wol gesatelt den chvenen Nibelvngen vant
###### 1868 | ### Do si cen rossen chomen di chvenege vnde ovch ir man ### Volker der starche raten daz began ### si solden bvhvrdiren nach ir landes siten ### des wart von den helden sit vil herlich geritten
###### 1869 | ### Der helt het in geraten des si doch niht verdroz ### der bvhvrt vnt daz shallen div wrden beide groz ### vffe den hoff vil witen chom vil manech man ### Ecle vnde Criemhilt daz selbe schowen began
| ### Vff den bvhvrt chomen sehs hvndert degene ### der Dieteriches rechen den gesten cegegene ### si wolden chvrcewile mit den Bvrgonden han ### het ers in gegvnnen si hetenz gerne getan
###### 1871 | ### Hey waz gvter rechen in da nach reit ### dem herren Dieteriche dæm wart daz geseit ### mit Gvntheres mannen daz spil er in verbot ### er vorhte siner manne des gie im sicherlichen not
###### 1872 | ### Do dise von Berne gescheiden waren dan ### do chomen von Bechelaren di Rvedegeres man ### fvnfhvndert vnder schilde fver den sal geritten ### liep wære dem margraven daz siz heten vermitten
| ### Do reit er wislichen zv zin dvrh di schar ### vnde sagete sinen degenen si wæren des gewar ### daz in vmmvte wæren di Gvntheres man ### ob si den bvhvrt liezen ez wære im liebe getan
###### 1874 | ### Do si von in geschieden di helde vil gemeit ### da chomen di von Dveringen als vns daz ist geseit ### vnt der von Tenemarchen wol tvsent chvener man ### von stichen sach man vliegen vil der [385a] trvnzvne dan
###### 1875 | ### Irnfrit vnde Hawart in den bvhvrt ritten ### ir heten di von Rine vil stolzlich erbitten ### si bvten manige tioste den von Dveringe lant ### des wart von stichen dverchel vil manich herlicher rant
| ### Do chom der herre Bloedelin mit drin tvsent dar ### Ecel vnd Criemhilt namen sin vil wol war ### wande vor in beiden div ritterschapft <geshach> ### div chveneginne ez gerne dvrch leit der Bvrgonden sach
###### 1877 | ### Scrvtan vnde Gybecke vf den bvhvrt ritten ### Ramvnch vnd Hornboge nach hivnisschen sitten ### si hielten gegen den helden von Bvrgonden lant ### di shefte dræten hohe veber des kvneges sals want
###### 1878 | ### Swes iemen da pflæge so was ez niwan schal ### man horte von schilde stoezzen palas vnde sal ### harte lvt erdiezzen von Gvntheres man ### den lob daz sin gesinde mit grozen eren gewan
| ### Do was ir chvrcewile so michel vnd groz ### daz dvrch di chovertvere der blanche sweiz do floz ### von den gvten rossen div di helde ritten ### si versvchtenz an di Hivnen mit vil hohvertegen sitten
###### 1880 | ### Do sprach der chvene recke Volker der spilman ### ich wæn vns dise recken tverren niht bestan ### ich hort ie sagen mære si wæren vns gehaz ### nvne chvndes sich gefvegen zware ninder baz
###### 1881 | ### Zen herbergen fveren sprach aber Volfger ### sol man vns di moere vnd riten danne mer ### gegen abende so des wirdet zit ### waz op div chvneginne den lop den Bvergonden git
| ### Do sahens einen riter so weigerlichen hie ### daz al der Hivnen getet deheiner nie ### ia moht er in den ziten wol haben hercentrvt ### er fvor so wol gechleidet sam eines edeln ritters prvt
###### 1883 | ### Do sprach aber Volker wi moeht ich daz verlan ### iener trvt der vrowen mvz ein gepveze han ### ez chvnde niemen gescheiden er gat im an den lip ### ichn rvche ich ob ez zverne des kvenech Eceln wip
###### 1884 | ### Nein dvrch mine liebe sprach der kvenech [385b] san ### ez wizent vns di livte vnd ob wir si bestan ### ir lat iz heben di Hivnen daz fveget sich noch baz ### dannoch der kvenech Ecel bi der chveneginne saz
| ### Ich wil den bvhvrt meren sprach do Hagene ### lat di vrowen schowen vnd di degene ### wi wir chvennen riten daz ist gvt getan ### man git doh lop deheinen des chvenech Gventheres man
###### 1886 | ### Volker der vil snelle den bvhvrt wider reit ### daz wart sit maniger vrowen vil groezliche leit ### er stach dem richen Hivnen daz sper dvrch sinen lip ### daz sach man sit beweinen beide maget vnd wip
###### 1887 | ### Vil harte hvrtechliche Hagen vnde sine man ### mit sehzech siner degene riten er began ### nach dem videlære da daz spil gesach ### Ecel vnde Criemhilt ez besheidenlichen sach
| ### Done wolden di dri kvenege den ir spileman ### bi den fianden niht ane hvte lan ### da wart von tvsent helden vil crepftelich geritten ### si taten daz si wolden in vil hohvertechlichen sitten
###### 1889 | ### Da der riche Hivne ce tode wart erslagen ### man horte sine mage rvoffen vnd chlagen ### do rvft al daz gesinde wer hat ez getan ### daz hat der videlære Volker der chvene spileman
###### 1890 | ### Nach swerten vnd nach schilden rieffen da zehant ### des margraven mage von der Hivnen lant ### si wolden Volkeren ce tode erslagen han ### der wirt vz einem venster vil harte gahen began
| ### Do hvb sich von den livten allenthalben schal ### di chvenege vnde ir gesinde erbeizten fver den sal ### div ross ce rvcke stiezen di Bvergonden man ### do chom der kvenech Ecel der herre ez scheiden began
###### 1892 | ### Ein des Hivnen mage den er bi im vant ### ein vil starchez waffen brach er im vz der hant ### do slvch ers alle widere wand im was vil zorn ### wi het ich minen dienest an disen helden verlorn
###### 1893 | ### ob ir hi bi mir slveget disen spilman ### sprach der kvenech Ecel daz wære missetan ### ich sach vil wol sin riten do er den Hivnen stach ### daz ez von einem strv^che an sine schvlde gesach [386a]
| ### Ir mvezet mine geste vride lazen han ### do wart ir geleite div ross div zoh man dan ### zv den herbergen si heten manegen kneht ### di im mit vlize waren zallem dieneste gereht
###### 1895 | ### Der wirt mit sinen frivnden in den palas gie ### zorn er mer deheinen da niht werden lie ### do rihte man di tissche daz <wâzer> man in trvch ### da heten di von Rine der starchen viende genvch
###### 1896 | ### Ê di herren gesazen des was harte lanch ### div Criemhilde sorge si ce sere twanch ### si sprach fverste von Berne ich sv^ches dinen rat ### helffe vnde genade min dinch mir angestlichen stat
| ### Des antwrte ir Hildebrant der recke lobelich ### swer sleht di Nibelvnge der tvt iz ane mich ### dvrch deheines shazes liebe ez mach im werden leit ### si sint noch vmbetwngen di snellen ritter gemeit
###### 1898 | ### Do sprach in sinen zvehten dar zv her Dieterich ### di bete la beliben chveneginne rich ### mir habent dine mage der leide niht getan ### daz ich di degen chvovene mit strite welle bestan
###### 1899 | ### Div bet dich lvecel eret vil edels fversten wip ### daz dv dinen magen rætest an den lip ### si chomen vf genade her in <diz> lant ### Sifrit ist vngerochen von der Dieteriches hant
| ### Do si der vntrwe an dem Bernære nine vant ### do lobtes also balde in Bloedelines hant ### eine riche marche di Nvdvnch ê besaz ### sit do slvch in Danchwart daz er der gabe gar vergaz
###### 1901 | ### Si sprach dv solt mir helffen herre Bloedelin ### ia sint in disem hvse di viande min ### di slvgen Sifriden den minen lieben man ### swer mir daz hilffet rechen dem bin ich immer vndertan
###### 1902 | ### Des antwrte ir Bloedelin vrowe nv wizzet daz ### iane getar ich in vor Eceln geraten cheinen haz ### wande er di dine mage vro vil gerne sihit ### tæt ich <in> iht ce leide der kvnech vertrvege mir sin niht
| ### Neina herre Bloedelin ich pin dir immer holt ### ia gib ich dir ce miete silber vnde golt ### vnde eine maget schoene daz Nvdvnges wip ### so maht dv gerne trivten den ir vil minne [386b] chlichen lip
###### 1904 | ### Daz lant zv den bvergen wil ich dir allez geben ### so maht dv ritter edel mit vrevden immer leben ### gewinnestv di marche da Nvdunch inne saz ### swaz ich dir gelobe hivte mit triwen leist ich dir daz
###### 1905 | ### Do der herre Blodelin di miete da vernam ### vnt daz im dvrch ir schoene div vrowe wol gezam ### mit strite wande er dienen daz minnechliche wip ### dar vmbe mvose der recke do verliesen den lip
| ### Er sprach cer chveneginne get wider in den sal ### ê is iemen werde innen so heb ich einen schal ### ez mvz erarnen Hagene daz er iv hat getan ### ich antwrte iv gebvnden des kvenech Gventheres man
###### 1907 | ### Nv waffent ivch sprach Blodelin alle mine man ### wir svln den vianden in di herberge gan ### des wil mich niht erlazen daz Eceln wip ### dar vmbe svln wir helde alle wagen den lip
###### 1908 | ### Do div chveneginne Bloedelinen lie ### in des strites willen ce thisse si do gie ### mit Ecel dem chvenege vnde ovch mit sinen man ### si hete swinde ræte an di geste getan
| ### Do der strit niht anders chvnde sin erhaben ### Criemhilt ir leit daz alte in ir hercen was begraben ### do hiez si tragen cen tihssen den Eceln svn ### wi chvnde ein wip dvrch rache immer vreislicher getvn
###### 1910 | ### Dar giengen an der stvnde di Eceln man ### si trvgen Ortlieben den ivngen kvenech dan ### zv der fversten thisse da ovch Hagen saz ### des mvse daz chint ersterben dvrch sinen mortlichen haz
###### 1911 | ### Do der kvenech riche sinen svn ersach ### zv sinen chonemagen er gvetliche sprach ### nv seht ir frivnt di mine daz ist min einech svn ### vnd ovch iwer swester daz mach iv allen wesen frvm
| ### Gevæhet er nach dem chvenne ez wirt ein chvene man ### rich vnd vil edel starch vnde wolgetan ### leb ich deheine wile ich gip im zwelf lant ### so mag [387a] iv wol gedienen des edeln Ortliebes hant
###### 1913 | ### Dar vmbe bit ich gerne ivch liebe frivnde min ### swenne ir ce lande ritet wider an den Rin ### so svlt ir mit iv fveren iwerr swester svn ### vnd svlt ovch an dem chinde vil genædechlichen tvn
###### 1914 | ### Vnde ziehet in cen eren vnz er werde ce man ### hat iv in dem lande iemen iht getan ### daz hilffet er iv rêchen <gewehsset> im sin lip ### di rede hort ovch Criemhilt des kvenech Eceln wip
| ### Im solden wol getrwen dise degene ### gevehs er ceinem manne so sprach Hagene ### doch ist der kvenech ivnge <so> veichlich getan ### man sol mich sehen selten ce hove nach Ortliebe gan
###### 1916 | ### Der chvenech an Hagenen blichte div rede was im leit ### swi niht dar vmbe redete der fverste vil gemeit ### ez betrvbete im sin herce vnde beswarete im den mvt ### done was der Hagen wille niht ce chvercewile gvt
###### 1917 | ### Ez tet den fversten allen mit dem kvenege we ### daz Hagen von sinem chinde het gesprochen ê ### daz siz vertragen solden daz was in vngemach ### sin wessen niht der mære waz von dem recken sit geschach

<<< Übersicht <<< vorige Seite nächste Seite >>>